@@ -573,7 +573,7 @@ class TerminalWindow(ScrollText):
                 result=s
         return result
 
-    def findVerbEditor(self,obj:str, verb:str)->ScrollText | None:
+    def findVerbEditor(self,obj:str, verb:str):
         searchverb=getsepfield(verb,0,'*') # Handle wildcards.
         for i in self.pages.tabs():
             w=self.pages.nametowidget(i)
